@@ -414,6 +414,9 @@ class DALLE(nn.Module):
             is_raw_image = len(image.shape) == 4
 
             if is_raw_image:
+                image_size = self.vae.image_size
+                assert tuple(image.shape[1:]) == (3, image_size, image_size), f'invalid image of dimensions {image.shape} passed in during training'
+
                 image = self.vae.get_codebook_indices(image)
 
             image_len = image.shape[1]
